==> wiki3_4_0.zip: wiki3_4_0/plugin/core/ListPage.pm <==
package plugin::core::ListPage;
############################################################
# 
# ڡɽץ饰
# 
############################################################
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	$self->{once} = $main::pagelist;
	return bless $self,$class;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	$wiki->set_title("ڡΰ");
	my @list = $wiki->get_page_list;
	@list = sort by_mod_date(@list);
	
	my $cnt = $cgi->param("cnt");
	if($cnt eq ""){ $cnt = 0; }
	my $row = $cnt * $self->{once};
	
	my $content;
	my $count = 0;
	
	foreach(@list){
		if($self->{once}==0 ||($count>=$row && $count<$row+$self->{once})){
			$content = $content.
				"<li><a href=\"$main::script_name?page=".Util::url_encode($_)."\">".
				Util::escapeHTML($_)."</a>".
				" - ".Util::format_date($wiki->get_last_modified($_)).
				"</li>\n";
		}
		$count++;
	}
	
	$content = "<ul>\n".$content."</ul>\n";
	
	# ڡѥ
	if($self->{once}!=0){
		$content .= "<p>[";
		my $pagecnt = 1;
		for(my $i=0;$i<$count;$i=$i+$self->{once}){
			if($cnt==$pagecnt-1){
				$content .= $pagecnt." ";
			} else {
				$content .= "<a href=\"$main::script_name?action=LIST&amp;cnt=".($pagecnt-1)."\">".$pagecnt."</a> ";
			}
			$pagecnt++;
		}
		$content .= "]</p>\n";
	}
	
	return $content;
}

#===========================================================
# ǥȤ뤿δؿ
#===========================================================
sub by_mod_date {
	my $mod1 = (stat(Util::make_filename($main::data_dir,Util::url_encode($a),"wiki")))[9];
	my $mod2 = (stat(Util::make_filename($main::data_dir,Util::url_encode($b),"wiki")))[9];
	
	if($mod1 > $mod2){
		return -1;
	} elsif($mod1 < $mod2){
		return 1;
	} else {
		return 0;
	}
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/core/ListPage.pm <==
############################################################
# 
# ڡɽץ饰
# 
############################################################
package plugin::core::ListPage;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	$self->{once} = $wiki->config('pagelist');
	my $cgi = $wiki->get_CGI;
	
	$wiki->set_title("ڡΰ");
	my @list = $wiki->get_page_list;
	@list = sort {
		my $mod1 = (stat(&Util::make_filename($wiki->config('data_dir'),&Util::url_encode($a),"wiki")))[9];
		my $mod2 = (stat(&Util::make_filename($wiki->config('data_dir'),&Util::url_encode($b),"wiki")))[9];
		return $mod2 <=> $mod1;
	} @list;
	
	my $cnt = $cgi->param("cnt");
	if($cnt eq ""){ $cnt = 0; }
	my $row = $cnt * $self->{once};
	
	my $content;
	my $count = 0;
	
	foreach(@list){
		if($self->{once}==0 ||($count>=$row && $count<$row+$self->{once})){
			$content = $content.
				"<li><a href=\"".$wiki->config('script_name')."?page=".Util::url_encode($_)."\">".
				Util::escapeHTML($_)."</a>".
				" - ".Util::format_date($wiki->get_last_modified($_)).
				"</li>\n";
		}
		$count++;
	}
	
	$content = "<ul>\n".$content."</ul>\n";
	
	# ڡѥ
	if($self->{once}!=0){
		$content .= "<p>[ ";
		my $pagecnt = 1;
		for(my $i=0;$i<$count;$i=$i+$self->{once}){
			if($cnt==$pagecnt-1){
				$content .= $pagecnt." ";
			} else {
				$content .= "<a href=\"".$wiki->config('script_name')."?action=LIST&amp;cnt=".($pagecnt-1)."\">".$pagecnt."</a> ";
			}
			$pagecnt++;
		}
		$content .= "]</p>\n";
	}
	
	return $content;
}

#===========================================================
# ǥȤ뤿δؿ
#===========================================================
sub by_mod_date {
	my $mod1 = (stat(&Util::make_filename($wiki->config('data_dir'),&Util::url_encode($a),"wiki")))[9];
	my $mod2 = (stat(&Util::make_filename($wiki->config('data_dir'),&Util::url_encode($b),"wiki")))[9];
	
	if($mod1 > $mod2){
		return -1;
	} elsif($mod1 < $mod2){
		return 1;
	} else {
		return 0;
	}
}

1;
